@@ -96,7 +96,8 @@ struct LambdaOptions : public SharedOptions
 
     int             xDropOff    = 0;
     int             band        = -1;
-    double          eCutOff     = 0;
+    double          minBitScore = 0;
+    double          maxEValue   = 1e-04;
     int             idCutOff    = 0;
     unsigned long   maxMatches  = 500;
 
@@ -203,7 +204,7 @@ parseCommandLine(LambdaOptions & options, int argc, char const ** argv)
 
     addSection(parser, "Output Options");
     addOption(parser, ArgParseOption("o", "output",
-        "File to hold reports on hits (.m* are blastall -m* formats; .m8 is tab-seperated, .m9 is tab-seperated with "
+        "File to hold reports on hits (.m* are blastall -m* formats; .m8 is tab-separated, .m9 is tab-separated with "
         "with comments, .m0 is pairwise format).",
         ArgParseArgument::OUTPUT_FILE,
         "OUT"));
@@ -247,6 +248,14 @@ parseCommandLine(LambdaOptions & options, int argc, char const ** argv)
     setMinValue(parser, "e-value", "0");
     setMaxValue(parser, "e-value", "100");
 
+    addOption(parser, ArgParseOption("", "bit-score",
+        "Output only matches that score above this threshold.",
+        ArgParseArgument::DOUBLE));
+    setDefaultValue(parser, "bit-score", "0");
+    setMinValue(parser, "bit-score", "0");
+    setMaxValue(parser, "bit-score", "1000");
+
+
     addOption(parser, ArgParseOption("n", "num-matches",
         "Print at most this number of matches per query.",
         ArgParseArgument::INTEGER));
@@ -646,7 +655,7 @@ parseCommandLine(LambdaOptions & options, int argc, char const ** argv)
     getOptionValue(buffer, parser, "output-columns");
     if (buffer == "help")
     {
-        std::cout << "Please specify the columns in this format -oc 'column1 column2', i.e. space-seperated and "
+        std::cout << "Please specify the columns in this format -oc 'column1 column2', i.e. space-separated and "
                   << "enclosed in single quotes.\nThe specifiers are the same as in NCBI Blast, currently "
                   << "the following are supported:\n";
         for (unsigned i = 0; i < length(BlastMatchField<>::implemented); ++i)
@@ -693,7 +702,7 @@ parseCommandLine(LambdaOptions & options, int argc, char const ** argv)
     getOptionValue(buffer, parser, "sam-bam-tags");
     if (buffer == "help")
     {
-        std::cout << "Please specify the tags in this format -oc 'tag1 tag2', i.e. space-seperated and "
+        std::cout << "Please specify the tags in this format -oc 'tag1 tag2', i.e. space-separated and "
                   << "enclosed in quotes. The order of tags is not preserved.\nThe following specifiers are "
                   << "supported:\n";
 
@@ -771,7 +780,8 @@ parseCommandLine(LambdaOptions & options, int argc, char const ** argv)
 
     getOptionValue(options.seedDeltaIncreasesLength, parser, "seed-delta-increases-length");
 
-    getOptionValue(options.eCutOff, parser, "e-value");
+    getOptionValue(options.maxEValue, parser, "e-value");
+    getOptionValue(options.minBitScore, parser, "bit-score");
     getOptionValue(options.idCutOff, parser, "percent-identity");
 
     getOptionValue(options.xDropOff, parser, "x-drop");
@@ -835,10 +845,9 @@ parseCommandLine(LambdaOptions & options, int argc, char const ** argv)
     // TODO always prescore 1
     getOptionValue(options.preScoring, parser, "pre-scoring");
 
-    //TODO reactivate
-//     if ((!isSet(parser, "pre-scoring")) &&
-//         (options.alphReduction == 0))
-//         options.preScoring = 1;
+    if ((!isSet(parser, "pre-scoring")) &&
+        (options.reducedAlphabet == options.transAlphabet))
+        options.preScoring = 1;
 
     getOptionValue(options.preScoringThresh, parser, "pre-scoring-threshold");
 //     if (options.preScoring == 0)
@@ -904,8 +913,9 @@ printOptions(LambdaOptions const & options)
               << "  db index type:            " << _indexEnumToName(options.dbIndexType) << "\n"
               << " OUTPUT (file)\n"
               << "  output file:              " << options.output << "\n"
+              << "  maximum e-value:          " << options.maxEValue << "\n"
+              << "  minimum bit-score:        " << options.minBitScore << "\n"
               << "  minimum % identity:       " << options.idCutOff << "\n"
-              << "  maximum e-value:          " << options.eCutOff << "\n"
               << "  max #matches per query:   " << options.maxMatches << "\n"
               << "  include subj names in sam:" << options.samWithRefHeader << "\n"
               << "  include seq in sam/bam:   " << options.samBamSeq << "\n"
